==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_checkbox.js <==
/*****************************************************
 * Extension script: CheckBox form object, supports only boolean values!
 *
 * INHERITS FROM obj_form_generic
 *    _me._disabled
 *    _me.__update
 *
 *****************************************************/
 
_me = obj_checkbox.prototype;
function obj_checkbox(){};

	/**
	 * @brief: CONSTRUCTOR, create checkbox HTML element to __eIN variable
	 * @date : 20.4.2006 17:46:08
	 **/
	_me.__constructor = function(sTitle){
		/* creates ELM directly, because simlicity of object */
		var elm = mkElement('input',{"type":'checkbox',"name":this._pathName+'main',"id":this._pathName+'main',"className":this._type});
		this._main.appendChild(elm);
		this.__eIN = elm.form[elm.name];
		this.__eIN.value = true;

		if (Is.Defined(sTitle)) this._title(sTitle);

		var me = this;
		this.__eIN.onclick = function(e){
			e = e || window.event;
			if (me._onclick) me._onclick(e);
			me.__exeEvent('onclick',e,{"owner":me});
		}
	};

	/**
	 * @brief : control element's "checked" html method
	 * @param : b - boolean value
	 * @return: bool;
	 * @date  : 20.4.2006 17:42:24
	 **/
	_me._value = function(b){
		return this._checked(b);
	};
	
	_me._checked = function(b)
	{
		if (Is.String(b))
		  b = parseInt(b);
		  
		if (Is.Defined(b))
			this.__eIN.checked = b?1:0;
		else
			return this.__eIN.checked?1:0;
	}
  
	_me._title = function(sTitle){
		var eLbl = this._main.getElementsByTagName('label');
			eLbl = eLbl[0] || false;

		if (sTitle){

			if (!eLbl){
			    var me = this;
			    eLbl = mkElement('label'); //,{"for":this.__eIN.id} somehow doesnt work on checkbox in contextemu
				eLbl.onclick = function(e) {
					me._value(!me._value());

					if (me._onclick) me._onclick(e);
					me.__exeEvent('onclick',e,{"owner":me});
				};

			    this._main.appendChild(eLbl);
			}
            this.__title = sTitle;
			eLbl.innerHTML = getLang(sTitle);
		}
		else
  		if (typeof sTitle != 'undefined'){
  		    if (eLbl) eLbl.parentNode.removeChild(eLbl);
  		    this.__title = '';
  		}

		eLbl = null;
		return this.__title;
  };

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_checkbox.js <==
/*****************************************************
 * Extension script: CheckBox form object, supports only boolean values!
 *
 * INHERITS FROM obj_form_generic
 *    _me._disabled
 *    _me.__update
 *
 *****************************************************/
 
_me = obj_checkbox.prototype;
function obj_checkbox(){};

	/**
	 * @brief: CONSTRUCTOR, create checkbox HTML element to __eIN variable
	 * @date : 20.4.2006 17:46:08
	 **/
	_me.__constructor = function(sTitle){
		/* creates ELM directly, because simlicity of object */
		var elm = mkElement('input',{"type":'checkbox',"name":this._pathName+'main',"id":this._pathName+'main'});
		this._main.appendChild(elm);
		//this._main.className = this._type;
		
		this.__eIN = elm.form[elm.name];
		this.__eIN.value = true;

		if (Is.Defined(sTitle)) this._title(sTitle);

		var me = this;
		this.__eIN.onclick = function(e){
			e = e || window.event;
			if (me._onclick) me._onclick(e);
			me.__exeEvent('onclick',e,{"owner":me});
		};

		this.__eIN.onchange = function(e){
			e = e || window.event;
			if (me._onchange) me._onchange(e);
			me.__exeEvent('onchange',e,{"owner":me});
		};
	};

	/**
	 * @brief : control element's "checked" html method
	 * @param : b - boolean value
	 * @return: bool;
	 * @date  : 20.4.2006 17:42:24
	 **/
	_me._value = function(b){
		return this._checked(b);
	};
	
	_me._checked = function(b)
	{
		if (Is.String(b))
		  b = parseInt(b);
		  
		if (Is.Defined(b))
			this.__eIN.checked = b?1:0;
		else
			return this.__eIN.checked?1:0;
	}
  
	_me._title = function(sTitle){
		var eLbl = this._main.getElementsByTagName('label');
			eLbl = eLbl[0] || false;

		if (sTitle){

			if (!eLbl){
			    var me = this;
			    eLbl = mkElement('label'); //,{"for":this.__eIN.id} somehow doesnt work on checkbox in contextemu
				eLbl.onclick = function(e) {
					if (me.__eIN.disabled) return false;

					me._value(!me._value());

					if (me._onclick) me._onclick(e);
					me.__exeEvent('onclick',e,{"owner":me});
				};

			    this._main.appendChild(eLbl);
			}
            this.__title = sTitle;
			eLbl.innerHTML = getLang(sTitle);
		}
		else
  		if (typeof sTitle != 'undefined'){
  		    if (eLbl) eLbl.parentNode.removeChild(eLbl);
  		    this.__title = '';
  		}

		eLbl = null;
		return this.__title;
  };
